require "fox"
require "responder"

include Fox

class TwoButtonUpdateWindow < FXMainWindow

  include Responder

  # Message identifiers for this class
  ID_TOGGLE_BUTTON = FXMainWindow::ID_LAST

  def initialize(app)
    # Invoke base class initialize first
    super(app, "Update Example", nil, nil, 
          DECOR_TITLE | DECOR_CLOSE)

    # Define the message map for the class
    FXMAPFUNC(SEL_COMMAND, ID_TOGGLE_BUTTON, 
              "onCommand")
    FXMAPFUNC(SEL_UPDATE,  ID_TOGGLE_BUTTON, 
              "onUpdate")

    # First button
    @button_one = FXButton.new(self, "Enable Button 2",
                               nil, self, 
                               ID_TOGGLE_BUTTON)
    @button_one_enabled = true

    # Second button
    @button_two = FXButton.new(self, "Enable Button 1", 
                               nil, self, 
                               ID_TOGGLE_BUTTON)
    @button_two.disable
    @button_two_enabled = false
  end

  def onCommand(sender, sel, ptr)
    # Update the application state
    @button_one_enabled = !@button_one_enabled
    @button_two_enabled = !@button_two_enabled
  end

  def onUpdate(sender, sel, ptr)
    # Update the buttons based on the application state
    @button_one_enabled ? 
      @button_one.enable : @button_one.disable
    @button_two_enabled ? 
      @button_two.enable : @button_two.disable
  end

end

def run
  application = FXApp.new("UpdateExample", 
                          "Sample programs")
  application.init(ARGV)
  main = TwoButtonUpdateWindow.new(application)
  application.create
  main.show(PLACEMENT_SCREEN)
  application.run
end

run
