require "fox"
require "responder"

include Fox

class RadioButtonHandlerWindow < FXMainWindow

  include Responder

  # Message identifiers for this class
  ID_EXECUTE_CHOICE,
  ID_CHOOSE_QUIT,
  ID_CHOOSE_ICON = enum(FXMainWindow::ID_LAST, 3)

  def initialize(app)
    # Invoke base class initialize first
    super(app, "Radio Button Handler", nil, nil, 
          DECOR_TITLE | DECOR_CLOSE)

    # Define the message map for the class
    FXMAPFUNC(SEL_COMMAND, ID_EXECUTE_CHOICE, 
              "onCmdExecuteChoice")
    FXMAPFUNC(SEL_COMMAND, ID_CHOOSE_QUIT, 
              "onCmdChooseQuit")
    FXMAPFUNC(SEL_COMMAND, ID_CHOOSE_ICON, 
              "onCmdChooseIcon")

    group = FXGroupBox.new(self, "Radio Test Group", 
                           LAYOUT_SIDE_TOP | 
                           FRAME_GROOVE | 
                           LAYOUT_FILL_X)
    FXRadioButton.new(group, "&Quit the application", 
                      self, ID_CHOOSE_QUIT, 
                      ICON_BEFORE_TEXT | 
                      LAYOUT_SIDE_TOP)
    FXRadioButton.new(group, "&Iconify the window", 
                      self, ID_CHOOSE_ICON, 
                      ICON_BEFORE_TEXT | 
                      LAYOUT_SIDE_TOP)
    FXButton.new(self, "&Do it now!", nil, self, 
                 ID_EXECUTE_CHOICE)

    @target = app
    @choice = FXApp::ID_QUIT
  end

  def onCmdChooseQuit(sender, sel, ptr)
    @target = getApp()
    @choice = FXApp::ID_QUIT
  end

  def onCmdChooseIcon(sender, sel, ptr)
    @target = self
    @choice = FXTopWindow::ID_ICONIFY
  end

  def onCmdExecuteChoice(sender, sel, ptr)
    @target.handle(self, MKUINT(@choice, SEL_COMMAND), 
                   nil)
  end
end

def run
  application = FXApp.new("RadioButton", "Sample programs")
  application.init(ARGV)
  main = RadioButtonHandlerWindow.new(application)
  application.create
  main.show(PLACEMENT_SCREEN)
  application.run
end

run
