##
# Simple script to help mirror the comp.lang.ruby
# traffic on to the ruby-talk mailing list.
#
# We are called periodically (say once every 20 minutes).
# We look on the news server for any articles that have a 
# higher message ID than the last message we'd sent 
# previously. If we find any, we read those articles,
# send them on to the mailing list, and record the
# new hightest message id.

require 'nntp'
require 'net/smtp'
require 'params'

include NNTP

##
# Send mail to the mailing-list. The mail must be
# from a list participant, although the From: line
# can contain any valid address
#

def send_mail(head, body)
  smtp = Net::SMTP.new
  smtp.start(Params::SMTP_SERVER)
  smtp.ready(Params::MAIL_SENDER, Params::MAILING_LIST) do |a|
    a.write head
    a.write "#{Params::LOOP_FLAG}\r\n"
    a.write "\r\n"
    a.write body
  end
end

##
# We store the mssage ID of the last news we received. 

begin
  last_news = File.open(Params::LAST_NEWS_FILE) {|f| f.read} .to_i
rescue
  last_news = nil
end

##
# Connect to the news server, and get the current
# message numbers for the comp.lang.ruby group
#
nntp = NNTPIO.new(Params::NEWS_SERVER)
raise "Failed to connect" unless nntp.connect
count, first, last = nntp.set_group(Params::NEWSGROUP)

##
# If we didn't previously have a number for the highest
# message number, we do now

if not last_news
  last_news = last
end

##
# Go to the last one read last time, and then try to get more.
# This may raise an exception if the number is for a 
# nonexistent article, but we don't care.

begin
  nntp.set_stat(last_news)
rescue 
end

##
# Finally read articles until there aren't any more,
# sending each to the mailing list.

new_last = last_news

begin
  loop do
    nntp.set_next
    head = ""
    body = ""
    new_last, = nntp.get_head do |line|
      head << line
    end

    # Don't sent on articles that the mail2news program has
    # previously forwarded to the newsgroup (or we'd loop)
    next if head =~ %r{^X-rubymirror:}

    nntp.get_body do |line|
      body << line
    end

    send_mail(head, body)
  end
rescue
end

##
# And record the new high water mark

File.open(Params::LAST_NEWS_FILE, "w") do |f|
  f.puts  new_last 
end  unless new_last == last_news
